@@ -1,6 +1,7 @@
-from auth.utils import get_session_user
 from django.utils.functional import SimpleLazyObject
 
+from djara.django.auth.utils import get_session_user
+
 
 def get_user(request):
     if not hasattr(request, '_cached_user'):
